@@ -33,6 +33,9 @@ class GitObject(github.GithubObject.NonCompletableGithubObject):
     This class represents GitObjects as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"sha": self._sha.value})
+
     @property
     def sha(self):
         """
