@@ -62,6 +62,9 @@ class Organization(Framework.TestCase):
         self.assertEqual(self.org.type, "Organization")
         self.assertEqual(self.org.url, "https://api.github.com/orgs/BeaverSoftware")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.org.__repr__(), 'Organization(name=None, id=1424031)')
+
     def testEditWithoutArguments(self):
         self.org.edit()
 
@@ -124,16 +127,17 @@ class Organization(Framework.TestCase):
         self.assertListKeyEqual(self.org.get_teams(), lambda t: t.name, ["Members", "Owners"])
 
     def testCreateRepoWithMinimalArguments(self):
-        repo = self.org.create_repo("TestPyGithub")
+        repo = self.org.create_repo(name="TestPyGithub")
         self.assertEqual(repo.url, "https://api.github.com/repos/BeaverSoftware/TestPyGithub")
 
     def testCreateRepoWithAllArguments(self):
         team = self.org.get_team(141496)
-        repo = self.org.create_repo("TestPyGithub2", "Repo created by PyGithub", "http://foobar.com", False, False, False, False, team)
+        repo = self.org.create_repo(name="TestPyGithub2", description="Repo created by PyGithub", homepage="http://foobar.com",
+                                    private=False, has_issues=False, has_wiki=False, has_downloads=False, team_id=team.id)
         self.assertEqual(repo.url, "https://api.github.com/repos/BeaverSoftware/TestPyGithub2")
 
     def testCreateRepositoryWithAutoInit(self):
-        repo = self.org.create_repo("TestPyGithub", auto_init=True, gitignore_template="Python")
+        repo = self.org.create_repo(name="TestPyGithub", auto_init=True, gitignore_template="Python")
         self.assertEqual(repo.url, "https://api.github.com/repos/BeaverSoftware/TestPyGithub")
 
     def testCreateFork(self):
